==> hp_pricebot-1.7.43.tgz: package/bot_controller.js <==
/*
Name:       Weslley De Souza
Date:       30.08.2017
Version:    2.0
Notes:      minimal Server

CHANGELOG:
07.09.17 Update is now with npm

 */

/* Libraries */
const exec        = require('child_process').exec
    , figlet      = require('figlet')
    , fs          = require('fs')
    , request     = require('request')
    , fetch       = require('node-fetch')
    , http        = require('http')
    , path        = require('path')
    , os          = require('os')
    , moment      = require('moment')
    , tr          = require('tor-request')
    , io          = require('socket.io-client')
    , parseString = require('xml2js').parseString;



//CLEAR TERMINAL
exec("sudo clear", puts);

//FUNCTIONS

//Output of exec commands
function puts(error, stdout, stderr) {
    console.log(stdout)
}

//get current external ip by doing a request
function showCurrentExternalIP(log=true) {
    return new Promise((resovle)=>{
        const rnd   = Math.floor(Math.random() * 6);
        const ipurl = [
            'http://ifconfig.co/ip',
            'http://whatismyip.akamai.com/',
            'http://ip.tyk.nu/',
            'http://tnx.nl/ip',
            'http://eth0.me/',
            'https://4.ifcfg.me/ip'
        ]
        try{
            const options = {
                url: ipurl[rnd],
                timeout: 9000
            };
            request(options, function (err, resp, body) {
                if(body){
                    if(log)console.log("Current IP: " +body);
                    resovle(body)
                }
                else {
                    showCurrentExternalIP(log)
                }
            })
        }
        catch (SynatxError)
        {
            console.error("error : showCurrentExternalIP")
            resovle(false)
        }
    })
}

//start the server and check for update
function init()  {
    //Output IP,Port, ServerStatus
    figlet('HotelPartner', function(err, data) {
        if (err) console.dir(err);

        console.log(data);
        console.log(os.hostname()+ " is running " + moment().format("DD.MM.YYYY HH:mm"));

        getVersion(true);
    });
}

//Reboot Bot by exec
function rebootBot() {
    exec("reboot",                    puts);
    exec("echo 123 | sudo -S reboot", puts);
}

//Restart bot
function restartBot() {
    exec("forever restartall",        puts);
    process.exit(1);
}

//Update server by comparing package.json with the newest version
function getVersion(log=false) {
    return new Promise(resolve=>{
        try{
            fs.readFile('/var/node/package.json','utf8', function read(err, data)
            {
                //Get Current version of bot
                const jsnpackage = JSON.parse(data);
                let currentversion = jsnpackage.dependencies.hp_pricebot.replace(`^`,'').replace(/ /g,'').replace(' ','').toString()

                //Compare version and update if needed
                exec('npm show hp_pricebot version', function(error, nv, stderr)
                {
                    let newversion = nv.replace(/ /g,'').toString();
                    if(parseFloat(newversion) > parseFloat(currentversion))
                    {

                        //Set new version to json file
                        jsnpackage.dependencies.hp_pricebot = newversion;

                        //Save json file
                        updateServer(jsnpackage);


                        if (log){
                            console.log('Current Version: '+currentversion +" There is a newer version: "+newversion);
                        }
                        resolve(newversion);
                    }
                    else
                    {
                        if (log){
                            console.info("Version: "+currentversion);
                        }
                        resolve(currentversion)
                    }
                });

            })
        }catch (SyntaxError){}
    })
}
function updateServer(package) {
    if(!package)return;

    //Override package.json file
    fs.writeFile('/var/node/package.json', JSON.stringify(package), 'utf8', function readFileCallback(err, data){
        if(err)console.log(err);

        else {

            console.log("restarting node for update")

            exec('rm -r /var/node/node_modules/hp_pricebot',puts);
            exec('forever restartall',puts);
            process.exit(0);
        }

    })

}


// -----------  ------------- END SERVER CONF----------------------------------


//###PREFERENCES
tr.TorControlPort.password = 'hotelpartner';


//###Export
module.exports = {
    "start"  :init,
    "reboot" :rebootBot,
    "restart":restartBot,
    "showExternalIP":showCurrentExternalIP,
    "version":getVersion,
    "fetch"  :fetch,
    "request":request,
    "http"   :http,
    "os"     :os,
    "exec"   :exec,
    "fs"     :fs,
    "time"   :moment,
    "io"     :io,
    "tor"    :tr,
    "parseXML":parseString
};

==> hp_pricebot-1.7.44.tgz: package/bot_controller.js <==
/*
Name:       Weslley De Souza
Date:       30.08.2017
Version:    2.0
Notes:      minimal Server

CHANGELOG:
07.09.17 Update is now with npm

 */

/* Libraries */
const exec        = require('child_process').exec
    , figlet      = require('figlet')
    , fs          = require('fs')
    , request     = require('request')
    , fetch       = require('node-fetch')
    , http        = require('http')
    , path        = require('path')
    , os          = require('os')
    , moment      = require('moment')
    , tr          = require('tor-request')
    , io          = require('socket.io-client')
    , parseString = require('xml2js').parseString;



//CLEAR TERMINAL
exec("sudo clear", puts);

//FUNCTIONS

//Output of exec commands
function puts(error, stdout, stderr) {
    console.log(stdout)
}

//get current external ip by doing a request
function showCurrentExternalIP(log=true) {
    return new Promise((resovle)=>{
        const rnd   = Math.floor(Math.random() * 6);
        const ipurl = [
            'http://ifconfig.co/ip',
            'http://whatismyip.akamai.com/',
            'http://ip.tyk.nu/',
            'http://tnx.nl/ip',
            'http://eth0.me/',
            'https://4.ifcfg.me/ip'
        ]
        try{
            const options = {
                url: ipurl[rnd],
                timeout: 9000
            };
           tr.request(options, function (err, resp, body) {
                if(body){
                    if(log)console.log("Current IP: " +body);
                    resovle(body)
                }
                else {
                    showCurrentExternalIP(log)
                }
            })
        }
        catch (SynatxError)
        {
            console.error("error : showCurrentExternalIP")
            resovle(false)
        }
    })
}

//start the server and check for update
function init()  {
    //Output IP,Port, ServerStatus
    figlet('HotelPartner', function(err, data) {
        if (err) console.dir(err);

        console.log(data);
        console.log(os.hostname()+ " is running " + moment().format("DD.MM.YYYY HH:mm"));

        getVersion(true);
    });
}

//Reboot Bot by exec
function rebootBot() {
    exec("reboot",                    puts);
    exec("echo 123 | sudo -S reboot", puts);
}

//Restart bot
function restartBot() {
    exec("forever restartall",        puts);
    process.exit(1);
}

//Update server by comparing package.json with the newest version
function getVersion(log=false) {
    return new Promise(resolve=>{
        try{
            fs.readFile('/var/node/package.json','utf8', function read(err, data)
            {
                //Get Current version of bot
                const jsnpackage = JSON.parse(data);
                let currentversion = jsnpackage.dependencies.hp_pricebot.replace(`^`,'').replace(/ /g,'').replace(' ','').toString()

                //Compare version and update if needed
                exec('npm show hp_pricebot version', function(error, nv, stderr)
                {
                    let newversion = nv.replace(/ /g,'').toString();
                    if(parseFloat(newversion) > parseFloat(currentversion))
                    {

                        //Set new version to json file
                        jsnpackage.dependencies.hp_pricebot = newversion;

                        //Save json file
                        updateServer(jsnpackage);


                        if (log){
                            console.log('Current Version: '+currentversion +" There is a newer version: "+newversion);
                        }
                        resolve(newversion);
                    }
                    else
                    {
                        if (log){
                            console.info("Version: "+currentversion);
                        }
                        resolve(currentversion)
                    }
                });

            })
        }catch (SyntaxError){}
    })
}
function updateServer(package) {
    if(!package)return;

    //Override package.json file
    fs.writeFile('/var/node/package.json', JSON.stringify(package), 'utf8', function readFileCallback(err, data){
        if(err)console.log(err);

        else {

            console.log("restarting node for update")

            exec('rm -r /var/node/node_modules/hp_pricebot',puts);
            exec('forever restartall',puts);
            process.exit(0);
        }

    })

}


// -----------  ------------- END SERVER CONF----------------------------------


//###PREFERENCES
tr.TorControlPort.password = 'hotelpartner';


//###Export
module.exports = {
    "start"  :init,
    "reboot" :rebootBot,
    "restart":restartBot,
    "showExternalIP":showCurrentExternalIP,
    "version":getVersion,
    "fetch"  :fetch,
    "request":request,
    "http"   :http,
    "os"     :os,
    "exec"   :exec,
    "fs"     :fs,
    "time"   :moment,
    "io"     :io,
    "tor"    :tr,
    "parseXML":parseString
};
